@@ -30,9 +30,10 @@
 #include <KMessageBox>
 #include <KLocalizedString>
 
+#include <kio_version.h>
+
 // Fcitx
 #include <fcitx-config/xdg.h>
-#include <fcitxqtconfiguifactory.h>
 
 // self
 #include "global.h"
@@ -40,7 +41,6 @@
 #include "subconfigparser.h"
 #include "subconfigwidget.h"
 #include "subconfigwidget_p.h"
-#include "plugindialog.h"
 namespace Fcitx
 {
 
@@ -190,28 +190,27 @@ void SubConfigWidget::openSubConfig()
     }
 }
 
+bool SubConfigWidget::launchGuiWrapper(const QString &path) {
+    QString wrapper = Global::instance()->testWrapper(path);
+
+    if (!wrapper.isEmpty()) {
+        QStringList args;
+        args << path;
+        return QProcess::startDetached(wrapper, args);
+    }
+    return false;
+}
+
 void SubConfigWidget::openPlugin()
 {
-    FcitxQtConfigUIWidget* widget = Global::instance()->factory()->create(m_subConfig->nativepath());
-    if (widget) {
-        QPointer<QDialog> pluginDialog(new PluginDialog(widget, 0));
-
-        pluginDialog->exec();
-        delete pluginDialog;
-        return;
-    }
+    launchGuiWrapper(m_subConfig->nativepath());
 }
 
 void SubConfigWidget::openNativeFile()
 {
     char *newpath = NULL;
 
-    FcitxQtConfigUIWidget* widget = Global::instance()->factory()->create(m_subConfig->nativepath());
-    if (widget) {
-        QPointer<QDialog> pluginDialog(new PluginDialog(widget, 0));
-
-        pluginDialog->exec();
-        delete pluginDialog;
+    if (launchGuiWrapper(m_subConfig->nativepath())) {
         return;
     }
 
@@ -267,7 +266,11 @@ void SubConfigWidget::openNativeFile()
     }
 
     if (newpath) {
+#if KIO_VERSION < QT_VERSION_CHECK(5, 31, 0)
         KRun::runUrl(QUrl(newpath), m_subConfig->mimetype().isEmpty() ? "text/plain" : m_subConfig->mimetype(), NULL);
+#else
+        KRun::runUrl(QUrl(newpath), m_subConfig->mimetype().isEmpty() ? "text/plain" : m_subConfig->mimetype(), NULL, KRun::RunFlags());
+#endif
         free(newpath);
     }
 }
